from typing import Optional
from pydantic import BaseModel


class ProfileBase(BaseModel):
    bio: Optional[str] = None
    full_name: Optional[str] = None
    avatar_url: Optional[str] = None


class ProfileCreate(ProfileBase):
    pass


class ProfileUpdate(ProfileBase):
    pass


class Profile(ProfileBase):
    id: int
    user_id: int

    class Config:
        from_attributes = True
