# NIKAME GENERATED — DO NOT EDIT DIRECTLY
from fastapi import APIRouter, Depends
from strawberry.fastapi import GraphQLRouter
from sqlalchemy.ext.asyncio import AsyncSession

from app.db.session import get_db
from app.graphql.schema import schema

async def get_context(db: AsyncSession = Depends(get_db)):
    return {"db": db}

router = GraphQLRouter(schema, context_getter=get_context)
