# NIKAME GENERATED — DO NOT EDIT DIRECTLY
import strawberry
from typing import List, Optional
from datetime import datetime
import uuid

{% for model_name, model in models.items() %}
@strawberry.type
class {{ model_name }}:
    {% for field_name, field in model.fields.items() %}
    {{ field_name }}: {{ field.strawberry_type }}
    {% endfor %}
{% endfor %}
